from tkinter import Tk, Label, Button, Entry, Frame



class AskForPassword:
    __has_instance = 0
    def __init__(self,**kws):
        """
        Constructor method

        Some arguments may be input as a dictionary as follows:
            user = "User_label"             # default is "User:"
            passw = "Pass_label"            # default is "Password:"
            asterisk = "\u263a"             # default is "*"
            ok = "OK_button"                # default is "OK"
            cancel = "Cancel_button"        # default is "Cancel"
            wtitle = "Window_title"         # default is "Type your password"
            caps_on = "Caps_Locked_label"   # default is "CAPS LOCKED"
            caps_off = "Caps_Unlocked_label"# default is "caps unlocked"
            
        """        
        kws.setdefault('user','User:')
        kws.setdefault('passw','Password:')
        kws.setdefault('asterisk','*')
        kws.setdefault('ok','OK')
        kws.setdefault('cancel','Cancel')
        kws.setdefault('wtitle','Type your password')
        kws.setdefault('caps_on','CAPS LOCKED')
        kws.setdefault('caps_off','caps unlocked')
        self.__kws = kws
        if AskForPassword.__has_instance == 0:
            largura_botoes = 15
            largura_entries = 30
            
            self.__user_pass = ['','']
            
            self.__tk = Tk()        
            self.__tk.title(kws['wtitle'])
            self.__tk.bind("<Key>", self.__key)

            self.__frame_entries = Frame(self.__tk,pady=10,padx=20)
            self.__frame_capital = Frame(self.__tk)
            self.__frame_buttons = Frame(self.__tk,pady=10,padx=20)
            self.__frame_entries.pack()
            self.__frame_capital.pack()
            self.__frame_buttons.pack()
            ## entries
            self.__user_label = Label(self.__frame_entries,text=kws['user'])
            self.__user_label.grid(row=0,column=0)            

            self.__user_entry = Entry(self.__frame_entries)
            self.__user_entry['width'] = largura_entries
            self.__user_entry.grid(row=0,column=1)
            self.__user_entry.focus()

            self.__pass_label = Label(self.__frame_entries,text=kws['passw'])
            self.__pass_label.grid(row=1,column=0)

            self.__pass_entry = Entry(self.__frame_entries,show=kws['asterisk'])
            self.__pass_entry['width'] = largura_entries
            self.__pass_entry.grid(row=1,column=1)
            ## capital
            self.__capital = Label(self.__frame_capital)
            self.__capital['fg'] = 'red'
            self.__capital.pack()
            
            ## buttons
            
            self.__button_ok = Button(self.__frame_buttons,text=kws['ok'])
            self.__button_ok['width'] = largura_botoes
            self.__button_ok['command'] = self.__retornook
            self.__button_ok.grid(row=0,column=0)
            
            
            self.__button_cancel = Button(self.__frame_buttons,text=kws['cancel'])            
            self.__button_cancel['width'] = largura_botoes
            self.__button_cancel['command'] = self.__retornocancel
            self.__button_cancel.grid(row=0,column=1)
            
            self.__tk.protocol('WM_DELETE_WINDOW', self.__retornocancel)
            AskForPassword.__has_instance = 1
            self.__tk.mainloop()
            
    def __retornocancel(self):
        AskForPassword.__has_instance = 0
        self.__tk.destroy()
        self.__tk.quit()

    def __retornook(self):
        AskForPassword.__has_instance = 0
        self.__user_pass = (self.__user_entry.get(),AskForPassword.crypto(self.__pass_entry.get()))
        self.__tk.destroy()
        self.__tk.quit()
        
        

    def get(self):
        """This method returns a list [user,password] or ['',''] if canceled."""
        return self.__user_pass

    def has_user_pass(self,user_pass_list):
        """This method asserts whether 'user_pass_list' has a pair (user,password) correct."""
        User, Passw = self.__user_pass
        try:
            for user,passw in user_pass_list:
                if User==str(user) and Passw==str(passw):
                    return True
        except Exception as e:
            print('AskForPassword.has_user_pass:ERROR:',e)
            print(f'The {str(type(user_pass_list))[7:-1]} argument is invalid. Please, try a list of tuples, for example.')
            return None
        return False

    def __key(self,event):
        if event.keycode in [66] and event.state == 0:
            self.__capital['text'] = self.__kws['caps_on']
        elif event.keycode in [66] and event.state != 0:
            self.__capital['text'] = self.__kws['caps_off']
            
            

    def crypto(passw):
        """
        This method needs to be implemented to do encryption. It receives a string.
        You can implement, for example, by doing:

        def new_crypto(string):
            ans = ''
            for letter in string:
                ans += str(ord(letter)-103)
            return ans

        AskForPassword.crypto = new_crypto

        Now, you can use the method 'get()' and it returns [user,crypto_pass].
        """
        return passw
        
    








"""

Ask for Password GUI Interface
===========================

Based on Tkinter, this module offers a class called "AskForPassword" that
opens a window for the user to put its credentials.

.. code:: python
    from ask_for_color import AskForPassword
    ask = AskForPassword()
    user,password = ask.get()

My repository is in
.. _GitHub: https://github.com/jeykun/AskForPassword.git


THIS IS THE DOCUMENTATION OF THE CLASS
======================================
This class AskForPassword allows the user put its credentials.
    1) inputs as a dictionary (optional):
        -   user = "User_label"             # default is "User:"
        -   passw = "Pass_label"            # default is "Password:"
        -   asterisk = "\u263a"             # default is "*"
        -   ok = "OK_button"                # default is "OK"
        -   cancel = "Cancel_button"        # default is "Cancel"
        -   wtitle = "Window_title"         # default is "Type your password"
        -   caps_on = "Caps_Locked_label"   # default is "CAPS LOCKED"
        -   caps_off = "Caps_Unlocked_label"# default is "caps unlocked"
        



METHOD get()
------------
This method returns a list [user,password] or ['',''] if canceled.
See the next example:

.. code:: python
    from ask_for_password import AskForPassword
    ask = AskForPassword()
    user,pword = ask.get()  # it returns a string list like ['user','password']
    print(user,pword)

    

METHOD has_user_pass(user_pass_list)
------------------------------------
The method "has_user_pass(user_pass_list)" asserts whether 'user_pass_list' has a pair (user,password) correct.
The argument "user_pass_list" may be a list/tuple of pairs like [[user1,pass1],(user2,pass2)], etc.
It returns True whether user_pass_list has the 'user' and 'password' given by the user.
See the next example:

.. code:: python
    from ask_for_password import AskForPassword
    list_users = (['Alex','myPass'],['Joe','JoesPass'])
    ask = AskForPassword()
    user_allowed = has_user_pass(list_users)
    print(user_allowed)


    

METHOD crypto(password)
-----------------------
The method "crypto()" needs to be implemented to do encryption. Here goes the documentation:
This method needs to be implemented to do encryption. It receives a string.
You can implement, for example, by doing:

.. code:: python
    def new_crypto(string):
        ans = ''
        for letter in string:
            ans += str(ord(letter)-103)
        return ans
           
    AskForPassword.crypto = new_crypto

Now, you can use the method 'get()' and it returns [user,crypto_pass].
        




"""
from ask_for_password.ask_for_password import AskForPassword




"""
Based on Tkinter, this module offers a class called "AskForPassword" that
opens a window for the user to put its credentials.
>> get()
    To get the values, just use the "get( )" method. It returns the list ['user','password'].
    See the next example:
        from ask_for_password import AskForPassword
        ask = AskForPassword()
        user,pword = ask.get()  # it returns a string list like ['user','password']

>> has_user_pass(user_pass_list)
    The method "has_user_pass(user_pass_list)" asserts whether 'user_pass_list' has a pair (user,password) correct.
    The argument "user_pass_list" may be a list/tuple of pairs like [[user1,pass1],(user2,pass2)], etc.
    It returns True whether user_pass_list has the 'user' and 'password' given by the user.


>> crypto(password)
    The method "crypto()" needs to be implemented to do encryption. Here goes the documentation:
    This method needs to be implemented to do encryption. It receives a string.
    You can implement, for example, by doing:
       def new_crypto(string):
           ans = ''
           for letter in string:
               ans += str(ord(letter)-103)
           return ans
           
       AskForPassword.crypto = new_crypto

    Now, you can use the method 'get()' and it returns [user,crypto_pass].
        


run the command or follow the url
git clone https://github.com/jeykun/AskForPassword.git
"""
from setuptools import setup,find_packages
from codecs import open
from os import path
here = path.abspath(path.dirname(__file__))
try:
    with open(path.join(here,'DESCRIPTION.rst'), encoding='utf-8') as f:
        long_description = f.read()
except:
    long_description = ''


#ajuda em https://www.youtube.com/watch?v=Lb0b4ro0ze4&list=PLV7VqBqvsd_0u42lQtg4FU-rWeOSsbzOT&index=5
setup(
    # Ver PEP 426 (name)
    # Iniciar ou terminar com letra ou numero
    name='ask_for_password',
    # Ver PEP 440
    # O formato pode ser assim:
    # 1.2.0.dev1    Development release
    # 1.2.0a1       Alpha Release
    # 1.2.0b1       Beta Release
    # 1.2.0rc1      Release Candidate
    # 1.2.0         Final Release
    # 1.2.0.post1   Post Release
    # 15.10         Date based release
    # 23            Serial release
    version = '0.0.1',
    description = 'A GUI interface to get an user and a password list as [user,pass].',
    #long_description = 'Using Tkinter module, it allows the user to set any color in RGB system like "#rrggbb".',
    url = 'https://github.com/jeykun/AskForPassword.git',
    author = 'Junior R. Ribeiro',
    author_email = 'juniorribeiro2013@gmail.com',
    license = 'Free for non-commercial use',
    classifiers = [
        # How mature is this project? Common values are
        #   2   Alpha
        #   4   Beta
        #   5   Production/Stable
        'Development Status :: 5 - Production/Stable',
        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: User Interfaces',
        # Pick your license as you wish (should match "license" above)
        'License :: Free for non-commercial use',
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        ],
    keywords = ['GUI','Tkinter','Password','Interface'],
    packages = find_packages(),
    install_requires = ['sh>=1.11'],
    data_files = []    
    )
